conflict90s: Conflicts in the 90s
Description
A relational dataset recording the total number of militarized disputes
or events between countries in the 1990s, along with nodal and dyadic
covariates.format
A list consisting of a sociomatrix conflicts, an array of
dyadic covariates dyadvars and nodal covariates nodevars.source
Michael Ward.