Y and a nodal attribute matrix X.The dyadic variables in Y include three binary networks: advice, friendship
and co-worker status.
The categorical nodal attributes in X are coded as follows:
seniority and age are given in years, and female is
a binary indicator.