E.T
Array of square residual relational matrix series with additive
effects and covariates subtracted out. The third dimension of the array is
for different replicates. Each slice of the array according to the third
dimension is a square residual relational matrix.