Learn R Programming

amen (version 1.1)

raSab_bin_fc: Simulate a and Sab from full conditional distributions under bin likelihood

Description

Simulate a and Sab from full conditional distributions under bin likelihood

Usage

raSab_bin_fc(Z, Y, a, b, Sab, SS = round(sqrt(nrow(Z))))

Arguments

Z
a square matrix, the current value of Z
Y
square binary relational matrix
a
current value of row effects
b
current value of column effects
Sab
current value of Cov(a,b)
SS
number of iterations

Value

Z
new value of Z
Sab
new value of Sab
a
new value of a