Simulate a and Sab from full conditional distributions under the cbin likelihood
raSab_cbin_fc(Z, Y, a, b, Sab, odmax, odobs, SS =
round(sqrt(nrow(Z))))a square matrix, the current value of Z
square matrix of ranked nomination data
current value of row effects
current value of column effects
current value of Cov(a,b)
a scalar or vector giving the maximum number of nominations for each individual
observed outdegree
number of iterations
new value of Z
new value of Sab
new value of a