Metropolis update for dyadic correlation with independent replicate data.
rrho_mh_rep(E.T, rho, s2 = 1)Array of square residual relational matrix series. The third dimension of the array is for different replicates. Each slice of the array according to the third dimension is a square residual relational matrix.
current value of rho
current value of s2
a new value of rho