Rdocumentation
powered by
Learn R Programming
amen (version 1.1)
rZ_ord_fc: Simulate Z given the partial ranks
Description
Simulates a random latent matrix Z given its expectation, dyadic correlation and partial rank information provided by W
Usage
rZ_ord_fc(Z, EZ, rho, Y)
Arguments
Z
a square matrix, the current value of Z
EZ
expected value of Z
rho
dyadic correlation
Y
matrix of ordinal data
Value
a square matrix, the new value of Z