raSab_cbin_fc: Simulate a and Sab from full conditional distributions under the cbin
Description
Simulate a and Sab from full conditional distributions under the cbin
likelihoodUsage
raSab_cbin_fc(Z, Y, a, b, Sab, odmax, odobs, SS =
round(sqrt(nrow(Z))))
Arguments
Z
a square matrix, the current value of Z
Y
square matrix of ranked nomination data
a
current value of row effects
b
current value of column effects
Sab
current value of Cov(a,b)
odmax
a scalar or vector giving the maximum number of nominations for
each individual
Value
Znew value of Z Sabnew value of Sab anew
value of a