Usage
raSab_frn_fc(Z, Y, YL, a, b, Sab, odmax, odobs, SS =
round(sqrt(nrow(Z))))
Arguments
Z
a square matrix, the current value of Z
Y
square matrix of ranked nomination data
YL
list of ranked individuals, from least to most preferred in each
row
a
current value of row effects
b
current value of column effects
Sab
current value of Cov(a,b)
odmax
a scalar or vector giving the maximum number of nominations for
each individual