rrho_mh_rep: Metropolis update for dyadic correlation with independent replicate data
Description
Metropolis update for dyadic correlation with independent replicate data.
Usage
rrho_mh_rep(E.T, rho, s2 = 1)
Arguments
E.T
Array of square residual relational matrix series. The third
dimension of the array is for different replicates. Each slice of the array
according to the third dimension is a square residual relational matrix.